@@ -23,6 +23,8 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
+from translate.convert import convert
+from translate.misc.multistring import multistring
 from translate.storage import po, ts2
 
 
@@ -40,11 +42,19 @@ class ts2po:
         disambiguation,
         msgcomments,
         transtype,
+        hasplural,
     ):
         """Makes a pounit from the given message."""
         thepo = po.pounit(encoding="UTF-8")
-        thepo.addlocation("%s#%d" % (contextname, messagenum))
-        thepo.source = source
+        thepo.addlocation(f"{contextname}#{messagenum}")
+        # Handle plural forms: TS format stores only one source form (the plural),
+        # but PO needs both singular and plural. We duplicate the TS plural form for both.
+        if hasplural and isinstance(source, multistring):
+            # Use the plural form from TS as both singular and plural in PO
+            plural_form = source.strings[0] if source.strings else ""
+            thepo.source = multistring([plural_form, plural_form])
+        else:
+            thepo.source = source
         if not self.pot:
             thepo.target = target
         if len(disambiguation) > 0:
@@ -89,6 +99,7 @@ class ts2po:
                 disambiguation,
                 inputunit.getnotes(),
                 inputunit._gettype(),
+                inputunit.hasplural(),
             )
             thetargetfile.addunit(thepo)
 
@@ -107,8 +118,6 @@ def convertts(inputfile, outputfile, templates, pot=False, duplicatestyle="msgct
 
 
 def main(argv=None):
-    from translate.convert import convert
-
     formats = {"ts": ("po", convertts)}
     parser = convert.ConvertOptionParser(formats, usepots=True, description=__doc__)
     parser.add_duplicates_option()
